@@ -52,7 +52,7 @@ use vars qw($VERSION %minoltaLensTypes %minoltaTeleconverters %minoltaColorMode
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '2.14';
+$VERSION = '2.15';
 
 # Full list of product codes for Sony-compatible Minolta lenses
 # (ref http://www.kb.sony.com/selfservice/documentLink.do?externalId=C1000570)
@@ -500,31 +500,31 @@ my %metabonesID = (
    '65535.14' => 'Sony E 20mm F2.8',                #PH (SEL20F28   - 32798)
    '65535.15' => 'Sony E 35mm F1.8 OSS',            #25 (SEL35F18   - 32799)
    '65535.16' => 'Sony E PZ 18-105mm F4 G OSS',     #25 (SELP18105G - 32800)
-   '65535.17' => 'Sony E PZ 18-200mm F3.5-6.3 OSS', #25 (SELP18200  - 32807)
-   '65535.18' => 'Sony FE 55mm F1.8 ZA',            #25 (SEL55F18Z  - 32808)
-   '65535.19' => 'Sony FE 70-200mm F4 G OSS',       #25 (SEL70200G  - 32810)
-   '65535.20' => 'Sony FE 28-70mm F3.5-5.6 OSS',    #25 (SEL2870    - 32813)
+   '65535.17' => 'Sony E 18-50mm F4-5.6',           #25 (SEL1850    - 32803)
+   '65535.18' => 'Sony E PZ 18-200mm F3.5-6.3 OSS', #25 (SELP18200  - 32807)
+   '65535.19' => 'Sony FE 55mm F1.8 ZA',            #25 (SEL55F18Z  - 32808)
+   '65535.20' => 'Sony FE 70-200mm F4 G OSS',       #25 (SEL70200G  - 32810)
+   '65535.21' => 'Sony FE 28-70mm F3.5-5.6 OSS',    #25 (SEL2870    - 32813)
 #
 # 3rd party E lenses
 #
-   '65535.21' => 'Sigma 19mm F2.8 [EX] DN', #25
-   '65535.22' => 'Sigma 30mm F2.8 [EX] DN', #25
-   '65535.23' => 'Sigma 60mm F2.8 DN', #25
-   '65535.24' => 'Tamron 18-200mm F3.5-6.3 Di III VC', #25 (Model B011)
-   '65535.25' => 'Zeiss Touit 12mm F2.8', #25
-   '65535.26' => 'Zeiss Touit 32mm F1.8', #25
-   '65535.27' => 'Zeiss Touit 50mm F2.8 Macro', #25 
-# 
-# other lenses 
-# 
-   '65535.28' => 'Arax MC 35mm F2.8 Tilt+Shift', #JD 
-   '65535.29' => 'Arax MC 80mm F2.8 Tilt+Shift', #JD 
-   '65535.30' => 'Zenitar MF 16mm F2.8 Fisheye M42', #JD 
-   '65535.31' => 'Samyang 500mm Mirror F8.0', #19 
-   '65535.32' => 'Pentacon Auto 135mm F2.8', #19 
-   '65535.33' => 'Pentacon Auto 29mm F2.8', #19 
-   '65535.34' => 'Helios 44-2 58mm F2.0', #19 
-
+   '65535.22' => 'Sigma 19mm F2.8 [EX] DN', #25
+   '65535.23' => 'Sigma 30mm F2.8 [EX] DN', #25
+   '65535.24' => 'Sigma 60mm F2.8 DN', #25
+   '65535.25' => 'Tamron 18-200mm F3.5-6.3 Di III VC', #25 (Model B011)
+   '65535.26' => 'Zeiss Touit 12mm F2.8', #25
+   '65535.27' => 'Zeiss Touit 32mm F1.8', #25
+   '65535.28' => 'Zeiss Touit 50mm F2.8 Macro', #25
+#
+# other lenses
+#
+   '65535.29' => 'Arax MC 35mm F2.8 Tilt+Shift', #JD
+   '65535.30' => 'Arax MC 80mm F2.8 Tilt+Shift', #JD
+   '65535.31' => 'Zenitar MF 16mm F2.8 Fisheye M42', #JD
+   '65535.32' => 'Samyang 500mm Mirror F8.0', #19
+   '65535.33' => 'Pentacon Auto 135mm F2.8', #19
+   '65535.34' => 'Pentacon Auto 29mm F2.8', #19
+   '65535.35' => 'Helios 44-2 58mm F2.0', #19
 );
 
 %minoltaTeleconverters = (
